@@ -50,10 +50,11 @@ Cswrite(Cstring *iot, char *bfr, int size)
 /* reparse() into a cstring
  */
 void
-Csreparse(Cstring *iot, char *buf, int size, mkd_flag_t flags)
+Csreparse(Cstring *iot, char *buf, int size, mkd_flag_t* flags)
 {
     MMIOT f;
-    ___mkd_initmmiot(&f, 0);
+    ___mkd_initmmiot(&f, 0, flags);
+
     ___mkd_reparse(buf, size, flags, &f, 0);
     ___mkd_emblock(&f);
     SUFFIX(*iot, T(f.out), S(f.out));
