@@ -3,6 +3,8 @@
 #include <stdio.h>
 
 #define __WITHOUT_AMALLOC 1
+#include "config.h"
+#include "markdown.h"
 #include "cstring.h"
 #include "tags.h"
 
@@ -41,7 +43,8 @@ typedef int (*stfu)(const void*,const void*);
 
 /* load in the standard collection of html tags that markdown supports
  */
-main()
+int
+main(void)
 {
     int i;
 
